@@ -1,4 +1,4 @@
-from .evm import evm
+from .evm_streams import evm_streams
 from .history import history
 from .project import project
 from .stats import stats
