@@ -19,10 +19,10 @@ from openapi_streams.model.addresses_types_address_response import AddressesType
 from openapi_streams.model.addresses_types_addresses_add import AddressesTypesAddressesAdd
 from openapi_streams.model.addresses_types_addresses_remove import AddressesTypesAddressesRemove
 from openapi_streams.model.addresses_types_addresses_response import AddressesTypesAddressesResponse
-from openapi_streams.model.addresses_types_delete_address_response import AddressesTypesDeleteAddressResponse
 from openapi_streams.model.addresses_types_uuid import AddressesTypesUUID
 from openapi_streams.model.advanced_options import AdvancedOptions
 from openapi_streams.model.block import Block
+from openapi_streams.model.get_native_balances import GetNativeBalances
 from openapi_streams.model.history_model import HistoryModel
 from openapi_streams.model.history_types_history_model import HistoryTypesHistoryModel
 from openapi_streams.model.history_types_history_response import HistoryTypesHistoryResponse
@@ -36,13 +36,16 @@ from openapi_streams.model.stream_types_uuid import StreamTypesUUID
 from openapi_streams.model.streams_filter import StreamsFilter
 from openapi_streams.model.streams_model import StreamsModel
 from openapi_streams.model.streams_status import StreamsStatus
+from openapi_streams.model.streams_trigger import StreamsTrigger
 from openapi_streams.model.streams_types_streams_model import StreamsTypesStreamsModel
 from openapi_streams.model.streams_types_streams_model_create import StreamsTypesStreamsModelCreate
 from openapi_streams.model.streams_types_streams_response import StreamsTypesStreamsResponse
 from openapi_streams.model.streams_types_streams_status_update import StreamsTypesStreamsStatusUpdate
 from openapi_streams.model.streams_types_uuid import StreamsTypesUUID
 from openapi_streams.model.transaction import Transaction
+from openapi_streams.model.trigger_output import TriggerOutput
 from openapi_streams.model.uuid import UUID
+from openapi_streams.model.usage_stats_streams import UsageStatsStreams
 from openapi_streams.model.usagestats_types_usage_stats_model import UsagestatsTypesUsageStatsModel
 from openapi_streams.model.webhook_types_i_tiny_payload import WebhookTypesITinyPayload
 from openapi_streams.model.webhook_types_i_webhook_un_parsed import WebhookTypesIWebhookUnParsed
